@@ -6,7 +6,7 @@
 #' @param ... optional parameters for including a button label if needed
 #'
 #' @return a HTML object to be included in the ui section of a shiny app
-#' @importFrom shiny HTML
+#' @import shiny
 #' @seealso \href{http://getbootstrap.com/components/#jumbotron}{Jumbotron}
 #' @examples  jumbotron("Hi Shiny!", "text to show", buttonLabel = "Click Me")
 #' @export
@@ -15,17 +15,12 @@ jumbotron <- function(header , content, button = TRUE,  ...){
   button_label = c(...)
 
   if (button){
-    HTML(paste0("<div class='jumbotron'>
-                <h1> ", header, "</h1>
-                <p>", content ,"</p>",
-                "<p><a class='btn btn-primary btn-lg' button id='tabBut'>", button_label, "</a></p>
-                </div>") )
+    div(class = "jumbotron",
+        h1(header), p(content), p(a(class = "btn btn-primary btn-lg button", id='tabBut', button_label)))
 
   } else {
-    HTML(paste0("<div class='jumbotron'>
-                <h1> ", header, "</h1>
-                <p>", content ,"</p>",
-                "</div>") )
+   div(class = "jumbotron", h1(header), p(content))
+
   }
 
 }
